==> trip-0.1.0.tar.gz: trip-0.1.0/tripstack/lsfunctions/LSLocator.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

static const char* const LSLocator_cxx_Version = 
"$Id: LSLocator.cxx,v 1.3 2000/11/13 21:43:21 kevin Exp $";


#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <fstream.h>
#include "LSLocator.hxx"
#include "NetworkAddress.h"
#include "cpLog.h"

LSLocator* LSLocator::_instance = 0;

LSLocator&
LSLocator::instance()
{
    if (!_instance)
    {
        _instance = new LSLocator();
    }
    return (*_instance);
}

void 
LSLocator::destroy(void)
{
    delete LSLocator::_instance;
    LSLocator::_instance = 0;
}

LSLocator::LSLocator()
{
#ifdef __linux__
    if (atexit(LSLocator::destroy) < 0)
    {
        cpLog(LOG_ALERT, "Failed to register with atexit()");
    };
#endif
    init();
}

void 
LSLocator::init()
{
    ///Read the config file and gather the list of LSs
    ///The string is in the form of LSHost:Port

    ifstream inF("./lsconfig.cfg");
    if(inF.bad())
    {
        ///Failed to read the config file
        cpLog(LOG_INFO, "Failed to read (./lsconfig.cfg)");
        exit(0);
    }

    char buf[80];
    while(inF.getline(buf, 80))
    {
        NetworkAddress addr(buf);
        char tBuf[256];
        sprintf(tBuf, "%s:%d", addr.getIpName().c_str(), addr.getPort());
        _lsList.push_back(tBuf);
    }
}

bool 
LSLocator::isTrustedLs(const string& lsIp)
{
    LSLocator::LSList::const_iterator itr;
    for(itr = _lsList.begin(); itr != _lsList.end(); itr++)
    {
        NetworkAddress addr(*itr);
        if(addr.getIpName() == lsIp)
        {
            return true;
        }
    }
    return false;
}

ostream&
operator<<(ostream& os, const LSLocator& lslocator)
{
    LSLocator::LSList::const_iterator itr;
    os << "LS host list:" << endl;
    for(itr = lslocator._lsList.begin(); itr != lslocator._lsList.end(); itr++)
    {
        os << (*itr) << endl;
    }
    return os;
}

==> trip-1.0.0.tar.gz: trip-1.0.0/tripstack/lsfunctions/LSLocator.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

static const char* const LSLocator_cxx_Version = 
"$Id: LSLocator.cxx,v 1.5 2001/02/02 23:58:02 sprajpat Exp $";


#include <cstdio>
#include <cstdlib>
#include <iostream>
#include <fstream.h>
#include "LSLocator.hxx"
#include "NetworkAddress.h"
#include "cpLog.h"

LSLocator::LSLocator()
{
    init();
}

void 
LSLocator::init()
{
    ///Read the config file and gather the list of LSs
    ///The string is in the form of LSHost:Port
    ///This is temporary, in long run the list of Peers
    ///should come from the Provisioning.

    ifstream inF("./lsconfig.cfg");
    if(inF.bad())
    {
        ///Failed to read the config file
        cpLog(LOG_INFO, "Failed to read (./lsconfig.cfg)");
        exit(0);
    }

    char buf[80];
    while(inF.getline(buf, 80))
    {
        NetworkAddress addr(buf);
        char tBuf[256];
        sprintf(tBuf, "%s:%d", addr.getIpName().c_str(), addr.getPort());
        _lsList.push_back(tBuf);
    }
}

bool 
LSLocator::isTrustedLs(const string& lsIp) const
{
    //Since port number of a LSPeer session is always fixed to 6069
    //No need to include port number in the comparision, just check the 
    //IP address only.
    LSLocator::LSList::const_iterator itr;
    for(itr = _lsList.begin(); itr != _lsList.end(); itr++)
    {
        NetworkAddress addr(*itr);
        if(addr.getIpName() == lsIp)
        {
            return true;
        }
    }
    return false;
}

ostream&
operator<<(ostream& os, const LSLocator& lslocator)
{
    LSLocator::LSList::const_iterator itr;
    os << "LS host list:" << endl;
    for(itr = lslocator._lsList.begin(); itr != lslocator._lsList.end(); itr++)
    {
        os << (*itr) << endl;
    }
    return os;
}
